@@ -1,16 +1,11 @@
 ## no critic (RequireUseStrict)
 package Tapper::Reports::DPath;
-# git description: v4.1.0-1-g62d4fb9
+# git description: v4.1.1-13-g63aed9c
 
-BEGIN {
-  $Tapper::Reports::DPath::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::DPath::VERSION = '4.1.1';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Extended DPath functionality for Tapper reports
-
-        use 5.010;
+$Tapper::Reports::DPath::VERSION = '5.0.0';
+use 5.010;
         use Moose;
 
         use Tapper::Model 'model', 'get_hardware_overview'; #, 'get_systems_id_for_hostname'
@@ -170,7 +165,7 @@ BEGIN {
                 my $dpath              = new Data::DPath::Path( path => $path );
                 $condition             = _fix_condition($condition) unless $puresqlabstract;
                 my %condition          = $condition ? %{ eval $condition } : (); ## no critic (ProhibitStringyEval)
-                my $rs = model('ReportsDB')->resultset('Report')->search
+                my $rs = model('TestrunDB')->resultset('Report')->search
                     (
                      {
                       %condition
@@ -186,7 +181,6 @@ BEGIN {
                                                peerport
                                                peerhost
                                                successgrade
-                                               reviewed_successgrade
                                                total
                                                failed
                                                parse_errors
@@ -262,7 +256,7 @@ BEGIN {
 
                 # if ($report->reportgrouptestrun) {
                 #         my $rgt_id = $report->reportgrouptestrun->testrun_id;
-                #         my $rgt_reports = model('ReportsDB')->resultset('ReportgroupTestrun')->search({ testrun_id => $rgt_id});
+                #         my $rgt_reports = model('TestrunDB')->resultset('ReportgroupTestrun')->search({ testrun_id => $rgt_id});
                 #         # say STDERR "\nrgt $rgt_id count: ", $rgt_reports->count;
                 # }
 
@@ -318,11 +312,11 @@ BEGIN {
                 # create report group stats
                 if ($report->reportgrouptestrun and $report->reportgrouptestrun->testrun_id)
                 {
-                        my $rgt_stats = model('ReportsDB')->resultset('ReportgroupTestrunStats')->find($rgt->testrun_id);
+                        my $rgt_stats = model('TestrunDB')->resultset('ReportgroupTestrunStats')->find($rgt->testrun_id);
                         unless ($rgt_stats and $rgt_stats->testrun_id)
                         {
                                 # This is just a fail-back mechanism, in case the "fix-missinging-groupstats" script has not yet been run.
-                                $rgt_stats = model('ReportsDB')->resultset('ReportgroupTestrunStats')->new({ testrun_id => $rgt->testrun_id});
+                                $rgt_stats = model('TestrunDB')->resultset('ReportgroupTestrunStats')->new({ testrun_id => $rgt->testrun_id});
                                 $rgt_stats->update_failed_passed;
                                 $rgt_stats->insert;
                         }
@@ -370,11 +364,11 @@ BEGIN {
         }
 1;
 
-
+__END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -439,21 +433,26 @@ Cache a result for a complete tapper::dpath on all reports.
 
 Return cached result for a complete tapper::dpath on all reports.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
-
-__END__
-
-
