@@ -1,14 +1,9 @@
 ## no critic (RequireUseStrict)
 package Tapper::Reports::DPath::TT;
-BEGIN {
-  $Tapper::Reports::DPath::TT::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::DPath::TT::VERSION = '4.1.1';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Mix DPath into Template-Toolkit templates
-
-        use 5.010;
+$Tapper::Reports::DPath::TT::VERSION = '5.0.0';
+use 5.010;
         use Moose;
         use Template;
         use Cwd 'cwd';
@@ -83,10 +78,7 @@ BEGIN {
                                                  testrundb_hostnames => \&testrundb_hostnames,
                                                  defined $self->substitutes ? ( %{$self->substitutes} ) : (),
                                                 }, \$outbuf)) {
-                        my $msg = "Error in Tapper::Reports::DPath::TT::render_template: ".$tt->error."\n";
-                        print STDERR $msg;
-                        return $msg if $self->debug;
-                        return '';
+                        die $tt->error;
                 }
                 return $outbuf;
         }
@@ -99,10 +91,6 @@ BEGIN {
 
                 if(not $tt->process($file, {}, \$outbuf)) {
                         die Template->error();
-                        my $msg = "Tapper::Reports::DPath::TT::render_template: $Template::ERROR\n";
-                        print STDERR $msg;
-                        return $msg if $self->debug;
-                        return '';
                 }
                 return $outbuf;
         }
@@ -110,11 +98,11 @@ BEGIN {
 
 1;
 
-
+__END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -149,20 +137,26 @@ Render template.
 Provide list of hosts from Tapper TestrunDB to be accessible in
 templates.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
-
-__END__
-
